@@ -1,4 +1,4 @@
-from .misc_functions import random_data, csv_to_mat, mat_to_np, rescale,clr, theoretical_lam, to_zarr, tree_to_matrix
+from .misc_functions import random_data, csv_to_mat, mat_to_np, rescale, clr, theoretical_lam, to_zarr    #, tree_to_matrix
 from .compact_func import Classo, pathlasso
 from .cross_validation import CV
 from .stability_selection import stability
