@@ -11,7 +11,7 @@ The first function compute a solution of a Lasso problem for a given lambda. The
 '''    
 
 
-def Classo_R4(pb,lam,e=1.):
+def Classo_R4(pb,lam):
     pb_type = pb.type      # can be 'Path-Alg' or 'DR'
     (m,d,k),(A,C,y)  = pb.dim,pb.matrix
     lamb,rho  = lam * pb.lambdamax, pb.rho
@@ -80,7 +80,7 @@ This function compute the the solution for a given path of lam : by calling the
 def pathlasso_R4(pb,path,n_active=False):
     n = pb.dim[0]
     BETA,SIGMA,tol = [],[],pb.tol
-
+    pb.type = 'DR'
     save_init = pb.init   
     pb.regpath = True
     pb.compute_param()
@@ -117,7 +117,7 @@ Class of problem : we define a type, which will contain as keys, all the paramet
 
 class problem_R4 :
     
-    def __init__(self,data,algo,rho,e=1.):
+    def __init__(self,data,algo,rho):
         self.N = 500000
         
         (A,C,y), self.dim = data, (data[0].shape[0],data[0].shape[1],data[1].shape[0])
